@@ -1,4 +1,4 @@
-import warnings
+from __future__ import unicode_literals
 from django.db import models
 from django import forms
 from django.conf import settings
@@ -22,45 +22,30 @@ class ImageCropField(models.ImageField):
         return (field_class, args, kwargs)
 
 
-#deprecated, as we now set the widget in the ModelAdmin
-class CropForeignKey(models.ForeignKey):
-    '''
-    A croppable image field contained in another model. Only works in admin
-    for now, as it uses the raw_id widget.
-    '''
-
-    def __init__(self, model, field_name, *args, **kwargs):
-        self.field_name = field_name
-        warnings.warn('Please use the ImageCroppingMixin in your ModelAdmin '
-                      'instead of a CropForeignKey!', DeprecationWarning)
-        super(CropForeignKey, self).__init__(model, *args, **kwargs)
-
-    def south_field_triple(self):
-        """
-        Return a suitable description of this field for South.
-        """
-        # We'll just introspect ourselves, since we inherit.
-        from south.modelsinspector import introspector
-        field_class = "django.db.models.fields.related.ForeignKey"
-        args, kwargs = introspector(self)
-        return (field_class, args, kwargs)
-
-
 class ImageRatioField(models.CharField):
-    def __init__(self, image_field, size, adapt_rotation=False,
-                 allow_fullsize=False, verbose_name=None, help_text=None,
-                 hide_image_field=False, size_warning=getattr(
+    def __init__(self, image_field, size='0x0', free_crop=False,
+                 adapt_rotation=False, allow_fullsize=False, verbose_name=None,
+                 help_text=None, hide_image_field=False,
+                 size_warning=getattr(
                      settings, 'IMAGE_CROPPING_SIZE_WARNING', False)):
         if '__' in image_field:
             self.image_field, self.image_fk_field = image_field.split('__')
         else:
             self.image_field, self.image_fk_field = image_field, None
-        self.width, self.height = size.split('x')
+
+        self.width, self.height = list(map(int, size.split('x')))
+        self.free_crop = free_crop
         self.adapt_rotation = adapt_rotation
         self.allow_fullsize = allow_fullsize
         self.size_warning = size_warning
         self.hide_image_field = hide_image_field
-        super(ImageRatioField, self).__init__(max_length=255, blank=True, verbose_name=verbose_name, help_text=help_text)
+        field_kwargs = {
+            'max_length': 255,
+            'blank': True,
+            'verbose_name': verbose_name,
+            'help_text': help_text
+        }
+        super(ImageRatioField, self).__init__(**field_kwargs)
 
     def contribute_to_class(self, cls, name):
         super(ImageRatioField, self).contribute_to_class(cls, name)
@@ -74,9 +59,12 @@ class ImageRatioField(models.CharField):
         }
 
     def formfield(self, *args, **kwargs):
+        ratio = self.width / float(self.height) if not self.free_crop else 0
+
         kwargs['widget'] = forms.TextInput(attrs={
-            'data-width': int(self.width),
-            'data-height': int(self.height),
+            'data-min-width': self.width,
+            'data-min-height': self.height,
+            'data-ratio': ratio,
             'data-image-field': self.image_field,
             'data-my-name': self.name,
             'data-adapt-rotation': str(self.adapt_rotation).lower(),
